BenchmarkResult class

Constructors

BenchmarkResult({required String label, required DateTime timestamp, required List<MeasurementSeries> series, String type = flutterProfileType})
BenchmarkResult.fromBytes(Uint8List bytes)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
label → String
User-provided label for the benchmark result. Can be empty.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
series → List<MeasurementSeries>
The measurement series contained in the benchmark.
final
timestamp → DateTime
User-provided timestamp of the result. Must be in UTC.
final
type → String
The type of the benchmark.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toBytes() → Uint8List
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

currentFormatVersion → const int
flutterProfileType → const String