MeasurementSeries class

Constructors

MeasurementSeries(String label, List<int> measurements)
MeasurementSeries.fromBytes(Uint8List bytes)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
label → String
final
measurements → List<int>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toBytes() → Uint8List
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited