runtimeThreshold property
The comparison will ignore measurements that are less than this long (in microseconds).
Implementation
final int runtimeThreshold;
The comparison will ignore measurements that are less than this long (in microseconds).
final int runtimeThreshold;